@@ -28,7 +28,18 @@ from .common import *
 from .response_id import ExtResponse
 from .types import ClassName, ConcreteClassName
 
-RESERVED_IDS = {"this", "self", "template", "true", "false", "null", "none"}
+RESERVED_IDS = {
+    "this",
+    "self",
+    "template",
+    "true",
+    "false",
+    "null",
+    "none",
+    "item",
+    "expr",
+    "typeof",
+}
 
 
 class ObjectContent(AstNode):
@@ -110,12 +121,12 @@ def validate_parent_type(node, ns: str, name: str, err_msg: str):
     container_type = node.parent_by_type(Object).gir_class
     if container_type and not container_type.assignable_to(parent):
         raise CompileError(
-            f"{container_type.full_name} is not a {parent.full_name}, so it doesn't have {err_msg}"
+            f"{container_type.full_name} is not a {ns}.{name}, so it doesn't have {err_msg}"
         )
 
 
 @decompiler("object")
-def decompile_object(ctx, gir, klass, id=None):
+def decompile_object(ctx: DecompileCtx, gir, klass, id=None):
     gir_class = ctx.type_by_cname(klass)
     klass_name = (
         decompile.full_name(gir_class) if gir_class is not None else "$" + klass
@@ -124,4 +135,5 @@ def decompile_object(ctx, gir, klass, id=None):
         ctx.print(f"{klass_name} {{")
     else:
         ctx.print(f"{klass_name} {id} {{")
+    ctx.push_obj_type(gir_class)
     return gir_class
